
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#include <glib-object.h>


G_BEGIN_DECLS

/* enumerations from "gdata-documents-service.h" */


GType gdata_documents_service_error_get_type (void);
#define GDATA_TYPE_DOCUMENTS_SERVICE_ERROR (gdata_documents_service_error_get_type())

G_END_DECLS

/* Generated data ends here */

